@@ -10,6 +10,7 @@ requires "v";
 has _txn => (
     traits => [qw(NoGetopt)],
     is => "rw",
+    clearer => "_clear_txn",
 );
 
 sub try_txn_begin {
@@ -25,9 +26,14 @@ sub try_txn_commit {
     my ( $self, $b ) = @_;
 
     if ( my $txn = $self->_txn ) {
-        $self->v("comitting transaction...");
-        $b->txn_commit($txn);
-        $self->_txn(undef);
+        if ( $self->can("dry_run") and $self->dry_run ) {
+            $self->v("rolling back transaction...");
+            $b->txn_rollback($txn);
+        } else {
+            $self->v("comitting transaction...");
+            $b->txn_commit($txn);
+        }
+        $self->_clear_txn;
         $self->v(" done\n");
     }
 }
